@@ -1,4 +1,4 @@
-#!/usr/local/bin/python3.10
+#!/usr/local/bin/python3.11
 # Copyright (C) 2016 J.F.Dockes
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -25,10 +25,12 @@ import rclexecm
 class RclBaseHandler(object):
     '''Base Object for simple extractors.
 
-    This implements the boilerplate code for simple extractors for
-    file types with a single document. The derived class would
-    typically need only to implement the html_text method to return
-    the document text in HTML format'''
+    This implements the boilerplate code for simple extractors for file types with a single
+    document. The derived class would typically need only to implement the html_text method to
+    return the document text in HTML format by default, but any output MIME value is also possible
+    by setting self.outputmimetype (do *not* call self.em.setmimetype(), the value would be
+    clobbered.
+    '''
     
     def __init__(self, em):
         self.em = em
