@@ -1,4 +1,4 @@
-#!/usr/local/bin/python3.10
+#!/usr/local/bin/python3.11
 # Copyright (C) 2014-2020 J.F.Dockes
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -39,6 +39,13 @@ import rclexecm
 import rclconfig
 
 _mswindows = (sys.platform == "win32")
+if _mswindows:
+    import platform
+    if platform.machine().endswith('64'):
+        # See comments in ../windows/mkinstdir.sh about the setup of the poppler installation
+        popplerdir = "poppler/Library/bin"
+    else:
+        popplerdir = "poppler32"
 
 # Test access to the poppler-glib python3 bindings ? This allows
 # extracting text from annotations.
@@ -103,6 +110,7 @@ class PDFExtractor:
         self.em = em
         self.tesseract = None
         self.extrameta = None
+        self.re_head = None
 
         self.config = rclconfig.RclConfig()
         self.confdir = self.config.getConfDir()
@@ -110,12 +118,12 @@ class PDFExtractor:
         # Avoid picking up a default version on Windows, we want ours
         if not _mswindows:
             self.pdftotext = rclexecm.which("pdftotext")
+        if _mswindows and not self.pdftotext:
+            self.pdftotext = rclexecm.which(popplerdir + "/pdftotext")
         if not self.pdftotext:
-            self.pdftotext = rclexecm.which("poppler/pdftotext")
-            if not self.pdftotext:
-                # No need for anything else. openfile() will return an
-                # error at once
-                return
+            # No need for anything else. openfile() will return an
+            # error at once
+            return
         self.pdftotextversion = self._popplerutilversion(self.pdftotext)
         # Check if we need to escape portions of text: old versions of pdftotext output raw
         # HTML special characters. Don't know exactly when this changed but it's fixed in 0.26.5
@@ -124,10 +132,11 @@ class PDFExtractor:
         else:
             self.needescape = True
 
+        # pdfinfo may be used to extract XML metadata and custom PDF properties
         if not _mswindows:
             self.pdfinfo = rclexecm.which("pdfinfo")
-        if not self.pdfinfo:
-            self.pdfinfo = rclexecm.which("poppler/pdfinfo")
+        if _mswindows and not self.pdfinfo:
+            self.pdfinfo = rclexecm.which(popplerdir + "/pdfinfo")
         if self.pdfinfo:
             self.pdfinfoversion = self._popplerutilversion(self.pdfinfo)
             # The user can set a list of meta tags to be extracted from the XMP metadata
@@ -138,6 +147,16 @@ class PDFExtractor:
                 self._initextrameta()
         #self.em.rclog(f"PDFINFOVERSION {self.pdfinfoversion}")
 
+        # Extracting the outline / bookmarks needs still another poppler command...
+        self.dooutline = self.config.getConfParam("pdfoutline")
+        if self.dooutline:
+            if not _mswindows:
+                self.pdftohtml = rclexecm.which("pdftohtml")
+            if _mswindows and not self.pdftohtml:
+                self.pdftohtml = rclexecm.which(popplerdir + "/pdftohtml")
+            if not self.pdftohtml:
+                self.dooutline = False
+            
         # Pdftk is optionally used to extract attachments. This takes
         # a hit on performance even in the absence of any attachments,
         # so it can be disabled in the configuration.
@@ -192,7 +211,6 @@ class PDFExtractor:
             self.pdfinfo = None
             return
 
-        self.re_head = re.compile(br'<head>', re.IGNORECASE)
         self.re_xmlpacket = re.compile(br'<\?xpacket[ 	]+begin.*\?>' +
                                        br'(.*)' + br'<\?xpacket[ 	]+end',
                                        flags = re.DOTALL)
@@ -227,7 +245,7 @@ class PDFExtractor:
             # here with writing to stdout:
             #    Error occurred during initialization of VM
             #    Could not allocate metaspace: 1073741824 bytes
-            # Maybe unsufficient resources when started from Python ?
+            # Maybe insufficient resources when started from Python ?
             # In any case, the important thing is to discard the
             # output, until we fix the error or preferably find a way
             # to do it with poppler...
@@ -329,6 +347,8 @@ class PDFExtractor:
 
     # metaheaders is a list of (nm, value) pairs
     def _injectmeta(self, html, metaheaders):
+        if self.re_head is None:
+            self.re_head = re.compile(br'<head>', re.IGNORECASE)
         metatxt = b''
         for nm, val in metaheaders:
             metatxt += self._metatag(nm, val) + b'\n'
@@ -515,7 +535,39 @@ class PDFExtractor:
         if annotsfield:
             self.em.setfield("pdfannot", annotsfield)
         return html
-    
+
+
+    def _process_outline(self):
+        import xml.sax
+        data = subprocess.check_output([self.pdftohtml, "-i", "-s", "-enc", "UTF-8", "-xml",
+                                 "-stdout", self.filename])
+        class OutlineHandler(xml.sax.ContentHandler):
+            def __init__(self):
+                self.outlinelevel = 0
+                self.page = 0
+                self.alltext = ""
+                self.initem = False
+            def startElement(self, name, attrs):
+                if name == "outline":
+                    self.outlinelevel += 1
+                elif name == "item" and self.outlinelevel:
+                    self.initem = True
+                    if "page" in attrs:
+                        self.alltext += f"[P. {attrs['page']}] "
+            def endElement(self, name):
+                if name == "item" and self.outlinelevel:
+                    self.initem = False
+                    self.alltext += "\n"
+                elif name == "outline":
+                    self.outlinelevel -= 1
+            def characters(self, content):
+                if self.initem:
+                    self.alltext += content
+        handler = OutlineHandler()
+        xml.sax.parseString(data, handler)
+        return handler.alltext
+
+        
     def _selfdoc(self):
         '''Extract the text from the pdf doc (as opposed to attachment)'''
         self.em.setmimetype('text/html')
@@ -544,22 +596,29 @@ class PDFExtractor:
                     ocrproc = None
                     html = _htmlprefix + rclexecm.htmlescape(data) + _htmlsuffix
                 except Exception as e:
-                    self.em.rclog("%s failed: %s" % (cmd, e))
+                    self.em.rclog(f"{cmd} failed: {e}")
                     pass
 
         if self.extrameta:
             try:
                 html = self._setextrameta(html)
             except Exception as err:
-                self.em.rclog("Metadata extraction failed: %s %s" %
-                              (err, traceback.format_exc()))
+                self.em.rclog(f"Metadata extraction failed: {err} {traceback.format_exc()}")
+
+        if self.dooutline:
+            try:
+                outlinetext = self._process_outline()
+                html = self._injectmeta(html, [("description" , outlinetext),])
+            except Exception as err:
+                self.em.rclog(f"Outline extraction failed: {err} {traceback.format_exc()}")
 
         if havepopplerglib:
             try:
                 html = self._process_annotations(html)
             except Exception as err:
-                self.em.rclog("Annotation extraction failed: %s %s" %
-                              (err, traceback.format_exc()))
+                self.em.rclog(f"Annotation extraction failed: {err} {traceback.format_exc()}")
+
+            
         return (True, html, "", eof)
 
 
