@@ -1,4 +1,4 @@
-#!/usr/local/bin/python3.10
+#!/usr/local/bin/python3.11
 # Copyright (C) 2014 J.F.Dockes
 #   This program is free software; you can redistribute it and/or modify
 #   it under the terms of the GNU General Public License as published by
@@ -23,24 +23,11 @@ import posixpath
 import fnmatch
 import datetime
 
-import rclexecm
 from zipfile import ZipFile
 
-try:
-    from recoll import rclconfig
-    from recoll import conftree
-    hasrclconfig = True
-except:
-    hasrclconfig = False
-# As a temporary measure, we also look for rclconfig as a bare
-# module. This is so that the intermediate releases of the filter can
-# ship and use rclconfig.py with the filter code
-if not hasrclconfig:
-    try:
-        import rclconfig
-        hasrclconfig = True
-    except:
-        pass
+import rclexecm
+import rclconfig
+import conftree
 
 # Note about file names (python 2.6. 2.7, don't know about 3.)
 #
@@ -53,7 +40,7 @@ if not hasrclconfig:
 # directly as an index into the catalog.
 #
 # When we send the file name data to the indexer, we have to serialize
-# it as byte string, we can't pass unicode objects to and fro. This
+# it as byte string, we can't pass unicode objects to and from. This
 # means that we have to test if the name is unicode. If it is, we send
 # the string encoded as utf-8. When reading, if the input is utf-8, we
 # turn it to unicode and use this to access the zip member, else we
@@ -125,7 +112,6 @@ class ZipExtractor:
                 pass
             ok = True
         except Exception as err:
-            self.em.rclog("extractone: failed: [%s]" % err)
             ok = False
         iseof = rclexecm.RclExecM.noteof
         if self.currentindex >= len(self.zip.namelist()) -1:
@@ -141,17 +127,16 @@ class ZipExtractor:
         self.currentindex = -1
         self.skiplist = []
 
-        if hasrclconfig:
-            config = rclconfig.RclConfig()
-            config.setKeyDir(os.path.dirname(filename))
-            usebaseskipped = config.getConfParam("zipUseSkippedNames")
-            if usebaseskipped:
-                skipped = config.getConfParam("skippedNames")
-                self.em.rclog("skippedNames: %s"%self.skiplist)
-                self.skiplist += conftree.stringToStrings(skipped)
-            skipped = config.getConfParam("zipSkippedNames")
-            if skipped is not None:
-                self.skiplist += conftree.stringToStrings(skipped)
+        config = rclconfig.RclConfig()
+        config.setKeyDir(os.path.dirname(filename))
+        usebaseskipped = config.getConfParam("zipUseSkippedNames")
+        if usebaseskipped:
+            skipped = config.getConfParam("skippedNames")
+            self.em.rclog("skippedNames: %s"%self.skiplist)
+            self.skiplist += conftree.stringToStrings(skipped)
+        skipped = config.getConfParam("zipSkippedNames")
+        if skipped is not None:
+            self.skiplist += conftree.stringToStrings(skipped)
         try:
             # Note: py3 ZipFile wants an str file name, which
             # is wrong: file names are binary. But it accepts an
@@ -173,6 +158,7 @@ class ZipExtractor:
             ipath = ipath.decode("utf-8")
             return self.extractone(ipath)
         except Exception as err:
+            self.em.rclog("extractone: failed: [%s]" % err)
             return (ok, data, ipath, eof)
         
     def getnext(self, params):
@@ -198,7 +184,7 @@ class ZipExtractor:
             #fixedname = entryname.encode('cp437').decode('euc-kr')
             #self.em.rclog("REENCODED: %s"%fixedname)
 
-            if hasrclconfig and len(self.skiplist) != 0:
+            if len(self.skiplist) != 0:
                 while self.currentindex < len(self.zip.namelist()):
                     entryname = self.zip.namelist()[self.currentindex]
                     for pat in self.skiplist:
