@@ -6,7 +6,7 @@
 #
 from builtins import range
 import sys, os.path, optparse
-sys.path.insert(0, sys.path[0]+"/msodump.zip")
+sys.path.insert(0, os.path.join(os.path.dirname(__file__), "msodump.zip"))
 import traceback
 
 from msodumper import ole, xlsstream, globals, node, xlsmodel, olestream
@@ -27,7 +27,7 @@ def equalsName (name, array):
 def isOleStream (dirname):
     """Determine whether or not a stream is an OLE stream.
 
-Accodring to the spec, an OLE stream is always named '\1Ole'."""
+According to the spec, an OLE stream is always named '\1Ole'."""
 
     name = [0x01, 0x4F, 0x6C, 0x65] # 0x01, 'Ole'
     return equalsName(dirname, name)
